#ifdef PLATFORM_MOBILE
precision lowp float;
#endif

uniform sampler2D backTexture;
uniform sampler2D outlineTexture;
uniform float cooldownValue; // the remaining cooldown normalized
uniform float alpha;

varying mediump vec2 texCoord;
varying float fragValue;


void main() {
	vec4 backColor = texture2D(backTexture, texCoord);
	vec4 outlineColor = texture2D(outlineTexture, texCoord);
	
	float finalAlpha = step(0.5, backColor.a + outlineColor.a) * alpha;
	
	// 0 is on cooldown, 1 is off cooldown
	float value = step(cooldownValue, fragValue);
	
	float greenAlpha = (1.0 - cooldownValue) * 0.3;
	
	vec3 offCdRgb = backColor.rgb * (1.0 - greenAlpha);
	offCdRgb.g += greenAlpha;
	
	vec3 rgb = offCdRgb * value;
	rgb.r += 1.0 - value;
	
	gl_FragColor = vec4(outlineColor.rgb * outlineColor.a + rgb * (1.0 - outlineColor.a), finalAlpha);
}
